pub struct EntityAttributeInstance { /* private fields */ }Expand description
An instance of an Entity Attribute.
Implementations
Sourceimpl EntityAttributeInstance
impl EntityAttributeInstance
Sourcepub fn new(attribute: EntityAttribute) -> Self
pub fn new(attribute: EntityAttribute) -> Self
Creates a new instance of an Entity Attribute.
Sourcepub fn new_with_value(attribute: EntityAttribute, base_value: f64) -> Self
pub fn new_with_value(attribute: EntityAttribute, base_value: f64) -> Self
Creates a new instance of an Entity Attribute with a value.
Sourcepub fn attribute(&self) -> EntityAttribute
pub fn attribute(&self) -> EntityAttribute
Gets the attribute.
Sourcepub fn base_value(&self) -> f64
pub fn base_value(&self) -> f64
Gets the base value of the attribute.
Sourcepub fn compute_value(&self) -> f64
pub fn compute_value(&self) -> f64
Gets the computed value of the attribute.
Sourcepub fn with_add_modifier(&mut self, id: &str, modifier: f64) -> &mut Self
pub fn with_add_modifier(&mut self, id: &str, modifier: f64) -> &mut Self
Sets an add modifier.
If the modifier already exists, it will be overwritten.
Returns a mutable reference to self.
Sourcepub fn with_multiply_base_modifier(
&mut self,
id: &str,
modifier: f64,
) -> &mut Self
pub fn with_multiply_base_modifier( &mut self, id: &str, modifier: f64, ) -> &mut Self
Sets a multiply base modifier.
If the modifier already exists, it will be overwritten.
Returns a mutable reference to self.
Sourcepub fn with_multiply_total_modifier(
&mut self,
id: &str,
modifier: f64,
) -> &mut Self
pub fn with_multiply_total_modifier( &mut self, id: &str, modifier: f64, ) -> &mut Self
Sets a multiply total modifier.
If the modifier already exists, it will be overwritten.
Returns a mutable reference to self.
Sourcepub fn with_modifier(
&mut self,
id: &str,
modifier: f64,
operation: EntityAttributeOperation,
) -> &mut Self
pub fn with_modifier( &mut self, id: &str, modifier: f64, operation: EntityAttributeOperation, ) -> &mut Self
Sets a value modifier based on the operation.
If the modifier already exists, it will be overwritten.
Returns a mutable reference to self.
Sourcepub fn remove_modifier(&mut self, id: &String)
pub fn remove_modifier(&mut self, id: &String)
Removes a modifier.
Sourcepub fn clear_modifiers(&mut self)
pub fn clear_modifiers(&mut self)
Clears all modifiers.
Sourcepub fn has_modifier(&self, id: &String) -> bool
pub fn has_modifier(&self, id: &String) -> bool
Checks if a modifier exists.